<?php
 /**
 * @package		Joomla.Site
 * @subpackage	com_contact
 * @copyright	Copyright (C) 2005 - 2013 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

// Included dependencies
$com_path = JPATH_SITE.'/components/com_content/';
require_once $com_path.'router.php';
require_once $com_path.'helpers/route.php';
require_once $com_path.'helpers/query.php';

// Prepare
JModelLegacy::addIncludePath($com_path . '/models', 'ContentModel');

JHtml::addIncludePath($com_path.'helpers');
JHtml::addIncludePath(T3_PATH.'/html/com_content');

JFactory::getLanguage()->load('com_content', JPATH_SITE);

// Register the helper class
JLoader::register('MagzHelper', T3_TEMPLATE_PATH . '/templateHelper.php');

// Set application parameters in model
$app        = JFactory::getApplication();
$db         = JFactory::getDbo();
$params     = JComponentHelper::getParams('com_content');
$input      = $app->input;
$menuParams = new JRegistry();
if ($menu = $app->getMenu()->getActive()) {
	$menuParams->loadString($menu->params);
}
$params->merge($menuParams);


// Get an instance of the generic articles model
$articles = JModelLegacy::getInstance('Articles', 'ContentModel', array('ignore_request' => true));

//params
$articles->setState('params', $params);

// Set the filters based on the module params
$articles->setState('list.start', $input->getUInt('limitstart', 0));
$articles->setState('list.limit', (int) $params->get('num_intro_articles', $app->getCfg('list_limit')));
$articles->setState('filter.published', 1);

// Access filter
$access = !JComponentHelper::getParams('com_content')->get('show_noauth');
$authorised = JAccess::getAuthorisedViewLevels(JFactory::getUser()->get('id'));
$articles->setState('filter.access', $access);
$articles->setState('filter.author_id', $this->item->user_id);

// Ordering
$articleOrderby		= $params->get('orderby_sec', 'rdate');
$articleOrderDate	= $params->get('order_date');
$categoryOrderby	= $params->def('orderby_pri', '');
$secondary			= ContentHelperQuery::orderbySecondary($articleOrderby, $articleOrderDate) . ', ';
$primary			= ContentHelperQuery::orderbyPrimary($categoryOrderby);
$articles->setState('list.ordering', $primary . ' ' . $secondary . ' a.created ');
$articles->setState('list.direction', $params->get('article_ordering_direction', 'ASC'));


// Filter by language
$articles->setState('filter.language', $app->getLanguageFilter());

$contact = $this->item;
$this->contact = $contact;
$items  = $articles->getItems();

if($params->get('show_pagination')){
	$this->pagination = $articles->getPagination();
}

//template params
$tplparams = JFactory::getApplication()->getTemplate(true)->params;
?>
<div class="user-info clearfix">
	<div class="avatar">
		<?php if(!empty($contact->image)) : ?>
		<img src="<?php echo htmlspecialchars($contact->image) ?>" alt="<?php echo $contact->name ?>" />
		<?php else: ?>
		<i class="no-avatar icon-user"></i>
		<?php endif ?>
	</div>
	<div class="info-contact">
	<span class="contact-name"><?php echo $contact->name ?></span>
	
	<div class="contact-links">
		<ul class="social-link">
		<?php
		foreach(range('a', 'e') as $char) :// letters 'a' to 'e'
			$link = $contact->params->get('link'.$char);
			$label = $contact->params->get('link'.$char.'_name');

			if( ! $link) :
				continue;
			endif;

			// Add 'http://' if not present
			$link = (0 === strpos($link, 'http')) ? $link : 'http://'.$link;

			// If no label is present, take the link
		?>
		<li>
			<a href="<?php echo $link; ?>" <?php echo $label ? '' : 'class="no-icon"' ?>>
				<?php if($label): ?>
					<i class="icon-<?php echo JApplication::stringURLSafe(strtolower($label)) ?>"></i>
					<span><?php echo $label; ?></span>
				<?php else: ?>
					<?php echo $link ?>
				<?php endif; ?>
			</a>
		</li>
		<?php endforeach; ?>
		</ul>
	</div>
	
	<div class="contact-desc"><?php echo $contact->misc; ?></div>

	<?php echo $this->loadTemplate('address'); ?>
	</div>
</div>

<div class="tpl-inf-wrapper clearfix">
	<div class="clearfix">

	<h2 class="posted-by">
		<?php echo JText::sprintf('TPL_USERPAGE_POST_BY', $contact->name) ?>
		<?php if($this->pagination): ?>
			<span class="user-total-post">( <?php echo JText::plural('TPL_USERPAGE_TOTAL_POST', $this->pagination->get('total')) ?> )</span>
		<?php endif ?>
	</h2>
	

	<?php if ($params->get('show_page_heading')) : ?>
	<h1><?php echo $this->escape($params->get('page_heading')); ?></h1>
	<?php endif; ?>

	<?php if(!empty($items)) : ?>

		<div class="switch-container clearfix">
			<ul class="tpl-layout-switch pull-right">
				<li class="to-list"><i class="icon-th-list"></i></li>
				<li class="to-grid active"><i class="icon-th-large"></i></li>
			</ul>
		</div>
		</div>
		<div id="infinity-cont" class="infinity-cont userpage<?php echo $params->get('pageclass_sfx'), ' grid-cols-' . max(1, min(12, $params->get('num_columns', 1))) ?> av-grid clearfix">
		<?php 

			$dispatcher = JDispatcher::getInstance();

			// Compute the article slugs and prepare introtext (runs content plugins).
			foreach ($items as $i => & $item)
			{
				$item->slug = $item->alias ? ($item->id . ':' . $item->alias) : $item->id;
				$item->catslug = ($item->category_alias) ? ($item->catid . ':' . $item->category_alias) : $item->catid;
				$item->parent_slug = ($item->parent_alias) ? ($item->parent_id . ':' . $item->parent_alias) : $item->parent_id;
				// No link for ROOT category
				if ($item->parent_alias == 'root') {
					$item->parent_slug = null;
				}

				$item->event = new stdClass();

				// Old plugins: Ensure that text property is available
				if (!isset($item->text))
				{
					$item->text = $item->introtext;
				}
				JPluginHelper::importPlugin('content');
				$results = $dispatcher->trigger('onContentPrepare', array ('com_content.featured', &$item, &$this->params, 0));

				// Old plugins: Use processed text as introtext
				$item->introtext = $item->text;

				$results = $dispatcher->trigger('onContentAfterTitle', array('com_content.featured', &$item, &$item->params, 0));
				$item->event->afterDisplayTitle = trim(implode("\n", $results));

				$results = $dispatcher->trigger('onContentBeforeDisplay', array('com_content.featured', &$item, &$item->params, 0));
				$item->event->beforeDisplayContent = trim(implode("\n", $results));

				$results = $dispatcher->trigger('onContentAfterDisplay', array('com_content.featured', &$item, &$item->params, 0));
				$item->event->afterDisplayContent = trim(implode("\n", $results));
			}

		?>

		<?php //render template ?>
		<?php foreach ($items as &$item) : ?>
			<?php
				$this->item = $item;
				echo $this->loadTemplate('item');
			?>
		<?php endforeach ?>
		

		<?php if ($tplparams->get('tpl_navigation_infinity', 1)) : ?>
			<?php if ($this->params->def('show_pagination', 2) == 1  || ($this->params->get('show_pagination') == 2 && $this->pagination->get('pages.total') > 1)) : ?>
			<nav id="page-nav" class="pagination">
				<?php
					$urlparams = '';
					if (!empty($this->pagination->_additionalUrlParams)){
						foreach ($this->pagination->_additionalUrlParams as $key => $value) {
							$urlparams .= '&' . $key . '=' . $value;
						}
					}

					$next = $this->pagination->limitstart + $this->pagination->limit;
					$nextlink = JRoute::_($urlparams . '&' . $this->pagination->prefix . 'limitstart=' . $next);
				?>
				<a id="page-next-link" href="<?php echo $nextlink ?>" data-limit="<?php echo $this->pagination->limit; ?>" data-start="<?php echo $this->pagination->limitstart ?>"></a>
			</nav>
			<?php endif; ?>
		<?php endif; ?>

		</div>
	<?php endif ?>

	<?php if ($this->params->def('show_pagination', 2) == 1  || ($this->params->get('show_pagination') == 2 && $this->pagination->get('pages.total') > 1)) : ?>

		<?php if ($tplparams->get('tpl_navigation_infinity', 1)) : ?>
			<div id="infinity-next" class="infinity-next hidden">
				<div class="inf-loader">
					<img alt="<?php echo JText::_('TPL_INFINITY_NEXT')?>" src="<?php echo T3_TEMPLATE_URL ?>/images/ajax-load.gif">
				</div>
				<div class="inf-button">
					<?php echo JText::_('TPL_INFINITY_NEXT')?>
				</div>
			</div>
		<?php else : ?>
			<div class="pagination">

				<?php if ($this->params->def('show_pagination_results', 1)) : ?>
					<p class="counter pull-right">
						<?php echo $this->pagination->getPagesCounter(); ?>
					</p>
				<?php  endif; ?>
						<?php echo $this->pagination->getPagesLinks(); ?>
			</div>
		<?php endif; ?>
		
	<?php endif; ?>
</div>
